==> jboss-common-beans-1.0.0.Final-sources.jar: org/jboss/common/beans/property/PropertiesEditor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.common.beans.property;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.Properties;

/**
 * A property editor for {@link java.util.Properties}.
 *
 * @author baranowb
 */
@SuppressWarnings("unchecked")
public class PropertiesEditor extends PropertyEditorSupport<Properties> {

    public PropertiesEditor() {
        super(Properties.class);
    }

    @Override
    public void setAsText(final String text) {
        if (PropertyEditors.isNull(text)) {
            setValue(null);
            return;
        }
        try {
            Properties props = new Properties();
            props.load(new ByteArrayInputStream(text.getBytes()));
            setValue(props);
        } catch (IOException e) {
            throw new IllegalArgumentException("Failed to parse properties.", e);
        }
    }
}

==> jboss-common-beans-2.0.1.Final-sources.jar: org/jboss/common/beans/property/PropertiesEditor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.common.beans.property;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.Properties;

/**
 * A property editor for {@link java.util.Properties}.
 *
 * @author baranowb
 */
@SuppressWarnings("unchecked")
public class PropertiesEditor extends PropertyEditorSupport<Properties> {

    public PropertiesEditor() {
        super(Properties.class);
    }

    @Override
    public void setAsText(final String text) {
        if (BeanUtils.isNull(text)) {
            setValue(null);
            return;
        }
        try {
            Properties props = new Properties();
            props.load(new ByteArrayInputStream(text.getBytes()));
            setValue(props);
        } catch (IOException e) {
            throw new IllegalArgumentException("Failed to parse properties.", e);
        }
    }
}
